
#include <windows.h>
#include <stdio.h>
#include "Capture.h"


#if defined (WIN32)
	#define IS_WIN32 TRUE
#else
	#define IS_WIN32 FALSE
#endif

#define IS_NT      IS_WIN32 && (BOOL)(GetVersion() < 0x80000000)
#define IS_WIN32S  IS_WIN32 && (BOOL)(!(IS_NT) && (LOBYTE(LOWORD(GetVersion()))<4))
#define IS_WIN95   (BOOL)(!(IS_NT) && !(IS_WIN32S)) && IS_WIN32


HINSTANCE hInst;   // current instance

LPCTSTR lpszAppName = "MyApp";
LPCTSTR lpszTitle   = "My Application"; 

// the rest of the stuff
//......................

BOOL RegisterWin95( CONST WNDCLASS* lpwc );


int APIENTRY WinMain( HINSTANCE hInstance, HINSTANCE hPrevInstance,
                      LPTSTR lpCmdLine, int nCmdShow)
{
   MSG      msg;
   HWND     hWnd; 
   WNDCLASS wc;

   wc.style         = CS_HREDRAW | CS_VREDRAW | CS_OWNDC;
   wc.lpfnWndProc   = (WNDPROC)WndProc;       
   wc.cbClsExtra    = 0;                      
   wc.cbWndExtra    = 0;                      
   wc.hInstance     = hInstance;              
   wc.hIcon         = LoadIcon (hInstance, lpszAppName); 
   wc.hCursor       = LoadCursor(NULL, IDC_ARROW);
   wc.hbrBackground = (HBRUSH)(COLOR_WINDOW+1);
   wc.lpszMenuName  = lpszAppName;              
   wc.lpszClassName = lpszAppName;              

   if ( IS_WIN95 )
   {
      if ( !RegisterWin95( &wc ) )
         return( FALSE );
   }
   else if ( !RegisterClass( &wc ) )
      return( FALSE );

   hInst = hInstance; 

   hWnd = CreateWindow( lpszAppName, 
                        lpszTitle,    
                        WS_OVERLAPPEDWINDOW, 
                        CW_USEDEFAULT, 0, 
                        CW_USEDEFAULT, 0,  
                        NULL,              
                        NULL,              
                        hInstance,         
                        NULL               
                      );

   if ( !hWnd ) 
      return( FALSE );

   ShowWindow( hWnd, nCmdShow ); 
   UpdateWindow( hWnd );         

   while( GetMessage( &msg, NULL, 0, 0) )   
   {
      TranslateMessage( &msg ); 
      DispatchMessage( &msg );  
   }

   return( msg.wParam ); 
}


BOOL RegisterWin95( CONST WNDCLASS* lpwc )
{
	WNDCLASSEX wcex;

   wcex.style         = lpwc->style;
   wcex.lpfnWndProc   = lpwc->lpfnWndProc;
   wcex.cbClsExtra    = lpwc->cbClsExtra;
   wcex.cbWndExtra    = lpwc->cbWndExtra;
   wcex.hInstance     = lpwc->hInstance;
   wcex.hIcon         = lpwc->hIcon;
   wcex.hCursor       = lpwc->hCursor;
   wcex.hbrBackground = lpwc->hbrBackground;
   wcex.lpszMenuName  = lpwc->lpszMenuName;
   wcex.lpszClassName = lpwc->lpszClassName;

   // Added elements for Windows 95.
   //...............................
   wcex.cbSize = sizeof(WNDCLASSEX);
   wcex.hIconSm = LoadImage(wcex.hInstance, lpwc->lpszClassName, 
                            IMAGE_ICON, 16, 16,
                            LR_DEFAULTCOLOR );
			
   return RegisterClassEx( &wcex );
}



LRESULT CALLBACK About( HWND hDlg,           
                        UINT message,        
                        WPARAM wParam,       
                        LPARAM lParam)
{
   switch (message) 
   {
       case WM_INITDIALOG: 
               return (TRUE);

       case WM_COMMAND:                              
               if (   LOWORD(wParam) == IDOK         
                   || LOWORD(wParam) == IDCANCEL)    
               {
                       EndDialog(hDlg, TRUE);        
                       return (TRUE);
               }
               break;
   }

   return (FALSE); 
}


#define MSG_LEN          1024

char msg[MSG_LEN+1];

BOOL CALLBACK CaptureDlg(HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lParam);


LRESULT CALLBACK WndProc( HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam )
{
   switch( uMsg )
   {
      case WM_COMMAND :
              switch( LOWORD( wParam ) )
              {
                 case IDM_TEST:
                        DialogBox(hInst, "CaptureDlg", hWnd, CaptureDlg);
                        break;

                 case IDM_ABOUT :
                        DialogBox( hInst, "AboutBox", hWnd, About );
                        break;

                 case IDM_EXIT :
                        DestroyWindow( hWnd );
                        break;
              }
              break;

      case WM_DESTROY :
              PostQuitMessage(0);
              break;

      default :
            return( DefWindowProc( hWnd, uMsg, wParam, lParam ) );
   }

   return( 0L );               
}

/*****************************************************************************
*  CaptureDlg
*
*  Creates a popup dialog which allows manipulation of the 
*  master volume control.
******************************************************************************/

BOOL CALLBACK CaptureDlg(HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lParam)
{
    switch (uMsg)
    {
        // init dialog
        //.............
        
        case WM_INITDIALOG:
               // capture joystick
               //.................

               if(joySetCapture(hDlg, JOYSTICKID1, 0, FALSE))
               {
                   MessageBox(hDlg, "Unable to capture the joystick", 
                              NULL, MB_OK);
                   EndDialog(hDlg, FALSE);
               }

               // set movement threshold
               //.......................
               
               {
                  UINT nThreshold;
                  
                  joyGetThreshold(JOYSTICKID1, &nThreshold);
                  
                  if (nThreshold < 100)
                  {
                      nThreshold = 100;
                      joySetThreshold(JOYSTICKID1, nThreshold);
                  }
               }
               return(TRUE);

        // joystick activity
        //..................

        case MM_JOY1BUTTONDOWN :
        case MM_JOY1BUTTONUP :
        case MM_JOY1MOVE :
               {
                  JOYINFO   ji;
                  JOYINFOEX jiex;

                  joyGetPos(JOYSTICKID1, &ji);
                  joyGetPosEx(JOYSTICKID1, & jiex);

                  // display axis positions
                  //.......................

                  SetDlgItemInt(hDlg, IDC_XPOS_EC, ji.wXpos, FALSE);
                  SetDlgItemInt(hDlg, IDC_YPOS_EC, ji.wYpos, FALSE);
                  SetDlgItemInt(hDlg, IDC_ZPOS_EC, ji.wZpos, FALSE);

                  if (jiex.dwFlags & JOY_RETURNR)
                      SetDlgItemInt(hDlg, IDC_RPOS_EC, jiex.dwRpos, FALSE);
                  else
                      SetDlgItemInt(hDlg, IDC_RPOS_EC, 0L, FALSE);

                  if (jiex.dwFlags & JOY_RETURNU)
                      SetDlgItemInt(hDlg, IDC_UPOS_EC, jiex.dwUpos, FALSE);
                  else
                      SetDlgItemInt(hDlg, IDC_UPOS_EC, 0L, FALSE);

                  if (jiex.dwFlags & JOY_RETURNV)
                      SetDlgItemInt(hDlg, IDC_VPOS_EC, jiex.dwVpos, FALSE);
                  else
                      SetDlgItemInt(hDlg, IDC_VPOS_EC, 0L, FALSE);

                  // display buttons pressed
                  //........................

                  CheckDlgButton(hDlg, IDC_BTN1_CHK, (ji.wButtons & JOY_BUTTON1) );
                  CheckDlgButton(hDlg, IDC_BTN2_CHK, (ji.wButtons & JOY_BUTTON2) );
                  CheckDlgButton(hDlg, IDC_BTN3_CHK, (ji.wButtons & JOY_BUTTON3) );
                  CheckDlgButton(hDlg, IDC_BTN4_CHK, (ji.wButtons & JOY_BUTTON4) );
               }
               break;

        // commands
        //.........

        case WM_COMMAND:
               switch ( LOWORD(wParam) )
               {
                  // close down
                  //...........

                  case WM_CLOSE:
                  case IDOK:
                  case IDCANCEL:
                         {
                            // release joystick capture
                            //.........................

                            joyReleaseCapture(JOYSTICKID1);
                            
                            EndDialog(hDlg, TRUE);
                         }
                         break;
               }
               break;

    }

    return (FALSE);
}









